/// <reference types="google.picker" />
import * as React from 'react';
import { MultiSelectFieldSortOption } from '../core/MultiSelectField';
export interface Constraints {
    'content-types'?: string[];
    'content-length'?: number;
    maxlength?: number;
    min?: number;
    max?: number;
    max_items?: number;
    format?: {
        regex: string;
        errorMessage: string;
    };
}
export interface SelectionOption {
    value: string;
    name?: string;
    thumbnailUrl?: string;
    label?: string;
    rightLabel?: string;
    default?: boolean;
    disabled?: boolean;
    helperText?: React.ReactNode;
    helperLink?: string;
    error?: boolean;
}
export declare type OptionsUrlHttpHeader = {
    key: string;
    value: string;
};
export interface Image {
    thumbnailUrl: string;
    id: string;
}
export declare type ViewId = 'all' | 'docs-images' | 'docs-images-and-videos' | 'docs-videos' | 'documents' | 'drawings' | 'folders' | 'forms';
export interface View {
    readonly viewId: ViewId;
    readonly setIncludeFolders?: boolean;
    readonly setSelectFolderEnabled?: boolean;
}
export interface PresentationProperty {
    type: string;
    name: string;
    default?: any;
    constraints?: Constraints;
    helper_text?: string;
    helper_link?: string;
    optional?: boolean;
    multiple?: boolean;
    searchable?: boolean;
    selectable?: boolean;
    options?: SelectionOption[];
    options_url?: string;
    options_url_http_headers?: OptionsUrlHttpHeader[];
    sortable?: MultiSelectFieldSortOption[];
    radioOptions?: SelectionOption[];
    exclusive?: boolean;
    provider?: string;
    auth_url?: string;
    verify_url?: string;
    verify_qs_param?: string;
    logout_url?: string;
    logout_qs_param?: string;
    background_color?: string;
    foreground_color?: string;
    icon_url?: string;
    developerKey?: string;
    accessToken?: string;
    accessTokenUrl?: string;
    title?: string;
    onChangeCallback?: (result: google.picker.ResponseObject) => void;
    views?: View[];
    singular_name?: string;
    properties?: PresentationProperty[];
    hide?: boolean;
    disable?: boolean;
    images_url?: string;
    sourceUrl?: string;
    backgroundColor?: string;
    hoveredBackgroundColor?: string;
    textColor?: string;
    file_type?: string;
}
export interface Strings {
    [key: string]: string;
}
export interface ApplicationVersion {
    id: string;
    name: string;
    description: string;
    presentationProperties: PresentationProperty[];
    strings: Strings;
    thumbnailUrl?: string;
    iconUrl?: string;
    websiteUrl?: string;
    configurableDuration?: boolean;
    embeddedUrlFormat?: string;
    sourceUrl?: string;
}
export interface Application {
    id: string;
    currentAppVersion: ApplicationVersion;
}
