import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import MomentUtils from '@date-io/moment';
import moment from 'moment';
import { DatePicker, MuiPickersUtilsProvider } from '@material-ui/pickers';
import Popover from '@material-ui/core/Popover';
import TodaySharpIcon from '@material-ui/icons/TodaySharp';
import CancelIcon from '@material-ui/icons/Cancel';
import CheckCircleIcon from '@material-ui/icons/CheckCircle';
import * as React from 'react';
import { makeStyles, createStyles } from '../../styles';
import Row from '../../layout/Row';
import Spacer from '../../layout/Spacer';
import TextField from '../TextField';
import ActionBar from '../ActionBar/v2';
const valueToMoment = (value) => value === null ? moment() : moment(value);
export const DateField = ({ value, onChange, onBlur, label = '', placeholder, helperText, error, disabled, minDate, maxDate, dateFormat = 'MMM DD YYYY', }) => {
    const classes = useStyles();
    // State
    const [date, setDate] = React.useState(() => valueToMoment(value));
    const [open, setOpen] = React.useState(false);
    // Refs
    const inputRef = React.useRef(null);
    // Memoizers
    const isDirty = React.useMemo(() => {
        return !date.isSame(value);
    }, [date, value]);
    // Callbacks
    const handleClose = React.useCallback(() => {
        setDate(valueToMoment(value));
        setOpen(false);
    }, [value]);
    const handleDone = React.useCallback(() => {
        onChange(date.format(dateFormat));
        setOpen(false);
    }, [onChange, date, dateFormat]);
    // Effects
    // Update state when value changes.
    React.useEffect(() => {
        setDate(valueToMoment(value));
    }, [value]);
    return (_jsxs(MuiPickersUtilsProvider, Object.assign({ utils: MomentUtils }, { children: [_jsx(TextField, { readOnly: true, ref: inputRef, icon: _jsx(TodaySharpIcon, { onClick: () => {
                        if (!disabled) {
                            setOpen(true);
                        }
                    } }, void 0), label: label, placeholder: placeholder, value: value === null ? '' : date.format(dateFormat), onClick: () => setOpen(true), onBlur: onBlur, helperText: helperText, error: error, disabled: disabled }, void 0), _jsxs(Popover, Object.assign({ open: open, anchorEl: inputRef.current, onClose: handleClose, anchorOrigin: {
                    vertical: 'bottom',
                    horizontal: 'center',
                }, transformOrigin: {
                    vertical: 'top',
                    horizontal: 'center',
                } }, { children: [_jsx(DatePicker, { variant: "static", value: date, 
                        // @ts-ignore
                        onChange: setDate, disabled: disabled, format: "MM/DD/YYYY", minDate: minDate, maxDate: maxDate }, void 0), _jsx("div", Object.assign({ className: classes.actionsContainer }, { children: _jsxs(Row, Object.assign({ className: classes.actions }, { children: [_jsx(ActionBar.Action, { icon: _jsx(CancelIcon, {}, void 0), color: "error", label: "Cancel", onClick: handleClose }, void 0), _jsx(Spacer, {}, void 0), _jsx(ActionBar.Action, { icon: _jsx(CheckCircleIcon, {}, void 0), color: "success", label: "Done", disabled: !isDirty, onClick: handleDone }, void 0)] }), void 0) }), void 0)] }), void 0)] }), void 0));
};
const useStyles = makeStyles((theme) => createStyles({
    actionsContainer: {
        padding: theme.spacing(3),
        paddingTop: 0,
    },
    actions: {
        paddingTop: theme.spacing(3),
        borderTop: `1px solid ${theme.actionBar.border}`,
    },
}));
export default DateField;
//# sourceMappingURL=DateField.js.map