import { jsx as _jsx } from "react/jsx-runtime";
import { action } from '@storybook/addon-actions';
import { useEffect, useState } from 'react';
import { disabledArgTypes } from '../../helpers/storybookConstants';
import Row from '../../layout/Row';
import DateField from './DateField';
export default {
    title: 'Components/DateField',
    component: DateField,
    argTypes: Object.assign({}, disabledArgTypes),
};
/**
 * Storybook tests require always accepting
 * datefield changes since it uses current date
 * and tests use saved date. We set the date to the one
 * that is saved in the storybook tests to avoid the
 * problem.
 */
const DEFAULT_DATE = '2022-09-02T00:00:00';
const Template = (args) => {
    const [value, setValue] = useState(args.value);
    useEffect(() => {
        setValue(args.value);
    }, [args.value]);
    const handleOnChange = (value) => {
        action('onChange')(value);
        setValue(value);
    };
    return (_jsx(Row, Object.assign({ inline: true }, { children: _jsx(DateField, Object.assign({}, args, { value: value, onChange: handleOnChange }), void 0) }), void 0));
};
export const Default = Template.bind({});
Default.args = {
    value: DEFAULT_DATE,
};
export const RangeRestrictions = Template.bind({});
RangeRestrictions.args = {
    value: DEFAULT_DATE,
    minDate: new Date(DEFAULT_DATE),
    maxDate: new Date(+new Date(DEFAULT_DATE) + 1000 * 60 * 60 * 24 * 7),
    helperText: 'Pick a date within this week',
};
export const Error = Template.bind({});
Error.args = {
    value: DEFAULT_DATE,
    error: true,
    helperText: 'Oops! Invalid date',
};
export const Disabled = Template.bind({});
Disabled.args = {
    value: DEFAULT_DATE,
    disabled: true,
};
//# sourceMappingURL=DateField.stories.js.map