import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import * as React from 'react';
import Overlay from '../../internal/Overlay';
import withStyles from '../withStyles';
import withThemeSelector from '../withThemeSelector';
import styles from './FileDropper.styles';
export class FileDropper extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            isDragging: false,
        };
        this.onDragOver = (e) => {
            e.preventDefault();
        };
        this.onDragEnter = (e) => {
            this.dragTarget = e.target;
            this.setState({ isDragging: true });
        };
        this.onDragLeave = (e) => {
            // guard against child elements firing ondragleave by making sure
            // dragleave is fired for the same element that started the drag
            if (e.target === this.dragTarget) {
                this.setState({ isDragging: false });
            }
        };
        this.onDrop = (e) => {
            e.preventDefault();
            this.setState({ isDragging: false });
            this.props.onDrop(e.dataTransfer.files);
        };
    }
    componentDidMount() {
        this.attachDragListeners();
    }
    componentWillUnmount() {
        this.removeDragListeners();
    }
    attachDragListeners() {
        document.addEventListener('dragover', this.onDragOver, false);
        document.addEventListener('dragenter', this.onDragEnter, false);
        document.addEventListener('dragleave', this.onDragLeave, false);
    }
    removeDragListeners() {
        document.removeEventListener('dragover', this.onDragOver);
        document.removeEventListener('dragenter', this.onDragEnter);
        document.removeEventListener('dragleave', this.onDragLeave);
    }
    render() {
        const { title, classes } = this.props;
        const { isDragging } = this.state;
        if (!isDragging)
            return null;
        return (_jsxs(_Fragment, { children: [_jsx(Overlay, { className: classes.overlay }, void 0), _jsx("div", Object.assign({ className: classes.root, onDrop: this.onDrop }, { children: _jsx("div", Object.assign({ className: classes.title }, { children: title }), void 0) }), void 0)] }, void 0));
    }
}
export default withThemeSelector(withStyles(styles)(FileDropper), 'dark');
//# sourceMappingURL=FileDropper.js.map