import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import FileField from '../FileField';
import Button from '../Button';
import { makeStyles, createStyles } from '../../styles';
import IconButton from '@material-ui/core/IconButton';
import HighlightOff from '@material-ui/icons/HighlightOff';
import CircularProgress from '../CircularProgress';
import ArrowUpwardIcon from '@material-ui/icons/ArrowUpward';
import InputHelperText from '../InputHelperText';
import CheckCircle from '@material-ui/icons/CheckCircle';
const maxItemSize = 5000000;
const FontUploader = ({ state = 'idle', value, label = 'Font(s) Uploader', onChange, onUpload, onError, onDelete, }) => {
    const isFileSizeExceeded = (item) => item.size > maxItemSize;
    const classes = useStyles();
    const validateFiles = (item) => {
        return [...item].map((file) => {
            if (isFileSizeExceeded(file)) {
                onError('Upload failed. File exceeds 5MB.');
            }
            return file;
        });
    };
    const isValid = (file) => !isFileSizeExceeded(file);
    const hasFiles = [...value].length > 0;
    const handleAdd = (item) => {
        validateFiles(item);
        onChange(mergeFileList(item));
    };
    const mergeFileList = (item) => {
        let dataTransfer = new DataTransfer();
        [...value, ...item].forEach((file) => dataTransfer.items.add(file));
        return dataTransfer.files;
    };
    return (_jsxs("div", { children: [_jsx(FileField, { accept: ['.woff', '.woff2', '.ttf'], value: value, label: label, multiple: true, onChange: handleAdd, helperText: _jsxs("span", { children: ["*IMPORTANT REQUIREMENT:\u00A0", _jsx("a", Object.assign({ href: "https://support.raydiant.com/hc/en-us/articles/360058232292#uploading_custom_fonts", target: "_blank" }, { children: "Learn more" }), void 0)] }, void 0) }, void 0), _jsx("div", Object.assign({ className: classes.wrapper, style: { listStyleType: 'none' } }, { children: [...value].map((item, index) => {
                    return (_jsxs("div", Object.assign({ className: classes.list }, { children: [_jsx("p", Object.assign({ className: state === 'error' || !isValid(item) ? classes.error : '' }, { children: item.name }), void 0), _jsx(IconButton, Object.assign({ className: state === 'error' || !isValid(item) ? classes.error : '', size: "small", edge: "end", onClick: () => onDelete(index) }, { children: _jsx(HighlightOff, {}, void 0) }), void 0)] }), index));
                }) }), void 0), hasFiles && state === 'idle' && (_jsx(Button, { onClick: onUpload, disabled: [...value].some((item) => !isValid(item)), fullWidth: true, icon: _jsx(ArrowUpwardIcon, {}, void 0), label: "Upload", color: "progress" }, void 0)), hasFiles && state === 'error' && (_jsxs(_Fragment, { children: [_jsx(Button, { className: classes.error, fullWidth: true, label: "Upload failed", color: "default", icon: "alertCircle", hideBorder: true }, void 0), _jsx(InputHelperText, { children: "Upload interrupted. Please try again." }, void 0)] }, void 0)), state === 'loading' && (_jsx(Button, { className: classes.loading, fullWidth: true, label: "Uploading", color: "default", icon: _jsx(CircularProgress, {}, void 0), hideBorder: true }, void 0)), state === 'success' && (_jsx(Button, { className: classes.success, fullWidth: true, label: "Uploaded!", color: "default", icon: _jsx(CheckCircle, { className: classes.successIcon }, void 0), hideBorder: true }, void 0))] }, void 0));
};
const useStyles = makeStyles((theme) => {
    return createStyles({
        wrapper: {
            marginBottom: theme.spacing(3),
        },
        list: {
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'space-between',
            '& > p': {
                marginLeft: theme.spacing(2),
                marginRight: theme.spacing(2),
                marginTop: theme.spacing(1),
                marginBottom: theme.spacing(1),
            },
        },
        loading: {
            boxShadow: 'none',
            '&:hover': {
                background: 'none',
                boxShadow: 'none',
            },
        },
        error: {
            color: theme.palette.error.main,
            boxShadow: 'none',
            '&:hover': {
                background: 'none',
                boxShadow: 'none',
            },
        },
        successIcon: {
            color: theme.palette.progress.main,
        },
        success: {
            boxShadow: 'none',
            '&:hover': {
                background: 'none',
                boxShadow: 'none',
            },
        },
    });
});
export default FontUploader;
//# sourceMappingURL=FontUploader.js.map