import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as React from 'react';
import { hasMissingChildValue, isElementSelected, sortChildrenBySelected, } from '../../helpers';
import FormHelperText from '../../internal/FormHelperText';
import Column from '../../layout/Column';
import withStyles from '../withStyles';
import styles from './ImagePickerField.styles';
import ImagePickerFieldOption from './ImagePickerFieldOption';
export class ImagePickerField extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            orderedChildren: [],
        };
    }
    static getDerivedStateFromProps(props, state) {
        // Only reorder children on mount and when the child options have changed.
        // We don't want to reorder as the user selects items.
        const shouldSortChildren = hasMissingChildValue(state.orderedChildren, 
        // @ts-ignore
        props.children);
        return shouldSortChildren
            ? // @ts-ignore
                { orderedChildren: sortChildrenBySelected(props.value, props.children) }
            : null;
    }
    render() {
        const { value, onChange, helperText, error, onBlur } = this.props;
        const { orderedChildren } = this.state;
        return (_jsx("div", Object.assign({ onBlur: onBlur }, { children: _jsxs(Column, { children: [orderedChildren.map((child) => {
                        const isOptionSelected = isElementSelected(value, child);
                        const optionValue = child.props.value;
                        return React.cloneElement(child, {
                            checked: isOptionSelected,
                            onClick: () => {
                                if (isOptionSelected) {
                                    onChange(value.filter((item) => item !== optionValue));
                                }
                                else {
                                    onChange([...value, optionValue]);
                                }
                            },
                        });
                    }), _jsx(FormHelperText, Object.assign({ error: error }, { children: helperText }), void 0)] }, void 0) }), void 0));
    }
}
ImagePickerField.defaultProps = {
    error: false,
    helperText: '',
    children: [],
};
export default Object.assign(withStyles(styles)(ImagePickerField), {
    Option: ImagePickerFieldOption,
});
//# sourceMappingURL=ImagePickerField.js.map