import * as React from 'react';
import { IconOptions } from '../Icon';
export interface InputProps {
    /** The value of the field */
    value?: string;
    /** The type of input */
    type?: 'text' | 'email' | 'password' | 'tel' | 'search' | 'url' | 'number' | 'time' | 'date';
    /** The placeholder text */
    placeholder?: string;
    /** Set to true to display a readOnly input */
    readOnly?: boolean;
    /** Set to true to display input with error */
    error?: boolean;
    /** Set to true to disable the input */
    disabled?: boolean;
    /** Set the max width */
    maxWidth?: number;
    /** Set the max character length of the input */
    maxLength?: number;
    /** Set the max numner of the input when type is number */
    max?: number;
    /** Set the min numner of the input when type is number */
    min?: number;
    /** Set to true to display as a textarea */
    multiline?: boolean;
    /** The height of the textarea */
    multilineHeight?: number | string;
    /** Set to true to auto focus the input */
    autoFocus?: boolean;
    /** Optional helper text */
    helperText?: React.ReactNode;
    /** Optional icon to display */
    icon?: React.ReactNode | IconOptions;
    /** Optional text mask, only works with type='text' and non-multiline */
    mask?: Array<string | RegExp> | ((value: string) => Array<string | RegExp>);
    /** Set to false to disable the mask guide while typing */
    maskGuide?: boolean;
    /** The mask's placeholder character (defaults to '_') */
    maskPlaceholderChar?: string;
    /** Preserves the text positions when deleting characters in a masked input */
    keepCharPositions?: boolean;
    /** A function to modify the value of a masked input */
    pipe?: (conformedValue: string, config: any) => false | string | {
        value: string;
        indexesOfPipedChars: number[];
    };
    /** Called when the value changes */
    onChange?: (value: string) => any;
    /** Called when the input loses focus */
    onBlur?: React.FocusEventHandler<any>;
    /** Called when the input becomes focused */
    onFocus?: React.FocusEventHandler<any>;
    /** Called when the input is clicked */
    onClick?: (event: React.MouseEvent<any>) => any;
    /** The test id of the input */
    testId?: string;
    inputProps?: any;
    className?: string;
}
export declare const Input: React.FunctionComponent<InputProps>;
declare const _default: React.ForwardRefExoticComponent<InputProps & React.RefAttributes<unknown>>;
export default _default;
