import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import * as React from 'react';
import CloseIcon from '@material-ui/icons/Close';
import SearchIcon from '@material-ui/icons/Search';
import FilterListIcon from '@material-ui/icons/FilterList';
import SwapVertIcon from '@material-ui/icons/SwapVert';
import SwapVertReverseIcon from '../../icons/SwapVertReverse';
import withStyles from '../withStyles';
import styles from './SearchBox.styles';
import Checkbox from '../Checkbox';
import ActionBar from '../ActionBar/v2';
import { isElementSelected } from '../../helpers';
export var SortType;
(function (SortType) {
    SortType[SortType["Default"] = 0] = "Default";
    SortType[SortType["Name"] = 1] = "Name";
})(SortType || (SortType = {}));
export const DEFAULT_SORT_MODE = {
    type: SortType.Default,
    isReverseSort: false,
};
export class SearchBox extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            isSearchMode: false,
            isSortMode: false,
            sortMode: DEFAULT_SORT_MODE,
        };
    }
    render() {
        const { value, options, searchTerm, onChange, onSearchChange, onSortChange, disabled, classes, } = this.props;
        const { isSearchMode, isSortMode, sortMode } = this.state;
        const numChecked = options
            .map((option) => isElementSelected(value, option))
            .filter((c) => c).length;
        const checked = options.length > 0 && numChecked === options.length;
        const indeterminate = options.length > 0 && numChecked > 0 && numChecked < options.length;
        const showingValue = options.map((option) => option.props.value);
        const multiSelectAction = (_jsx(Checkbox, { className: classes.checkBox, disabled: disabled, checked: checked, indeterminate: indeterminate, onClick: (e) => {
                e.preventDefault();
                if (checked || indeterminate) {
                    onChange(value.filter((item) => !showingValue.includes(item)));
                }
                else {
                    const newValue = showingValue.filter((v) => !value.includes(v));
                    onChange([...value, ...newValue]);
                }
            } }, void 0));
        const isDefaultSortMode = sortMode.type === SortType.Default;
        const isDefaultSortModeRevert = isDefaultSortMode && sortMode.isReverseSort;
        const isNameSortMode = sortMode.type === SortType.Name;
        const isNameSortModeRevert = isNameSortMode && sortMode.isReverseSort;
        const sortActionOptions = (_jsxs(_Fragment, { children: [_jsx(ActionBar.SelectOption, { label: "Default", icon: isDefaultSortModeRevert ? _jsx(SwapVertReverseIcon, {}, void 0) : _jsx(SwapVertIcon, {}, void 0), selected: isDefaultSortMode, onClick: () => {
                        const newSortMode = {
                            type: SortType.Default,
                            isReverseSort: isDefaultSortMode
                                ? !sortMode.isReverseSort
                                : false,
                        };
                        this.setState({ isSortMode: !isSortMode, sortMode: newSortMode });
                        onSortChange(newSortMode);
                    } }, void 0), _jsx(ActionBar.SelectOption, { icon: isNameSortModeRevert ? _jsx(SwapVertReverseIcon, {}, void 0) : _jsx(SwapVertIcon, {}, void 0), label: "Name", selected: isNameSortMode, onClick: () => {
                        const newSortMode = {
                            type: SortType.Name,
                            isReverseSort: isNameSortMode ? !sortMode.isReverseSort : false,
                        };
                        this.setState({ isSortMode: !isSortMode, sortMode: newSortMode });
                        onSortChange(newSortMode);
                    } }, void 0)] }, void 0));
        const sortAction = (_jsx(ActionBar.Select, Object.assign({ icon: _jsx(FilterListIcon, { className: classes.sortIcon }, void 0), open: isSortMode, onOpen: () => this.setState(({ isSortMode: prevIsSortMode }) => ({
                isSortMode: !prevIsSortMode,
            })), disabled: disabled }, { children: sortActionOptions }), void 0));
        const searchAction = isSearchMode ? (_jsx(ActionBar.Input, { autoFocus: true, label: "Search", disabled: disabled, maxWidth: 145, className: classes.searchInput, icon: _jsx(ActionBar.Action, { icon: _jsx(CloseIcon, { className: classes.closeIcon }, void 0), onClick: (e) => {
                    e.preventDefault();
                    this.setState({ isSearchMode: false });
                    onSearchChange('');
                } }, void 0), value: searchTerm, onChange: onSearchChange }, void 0)) : (_jsx(ActionBar.Action, { className: classes.searchInputWrapper, icon: _jsx(SearchIcon, { className: classes.searchIcon }, void 0), disabled: disabled, onClick: () => this.setState({ isSearchMode: true, isSortMode: false }) }, void 0));
        return (_jsxs(ActionBar, Object.assign({ className: classes.searchBox }, { children: [multiSelectAction, !isSearchMode && sortAction, searchAction] }), void 0));
    }
}
SearchBox.defaultProps = {
    value: [],
    options: [],
    searchTerm: '',
    disabled: false,
};
export default withStyles(styles)(SearchBox);
//# sourceMappingURL=SearchBox.js.map