import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { action } from '@storybook/addon-actions';
import { disabledArgTypes } from '../../helpers/storybookConstants';
import TextFieldDefault, { TextField } from './TextField';
export default {
    title: 'Components/TextField',
    component: TextField,
    argTypes: Object.assign({}, disabledArgTypes),
};
const Template = (args) => {
    const [value, setValue] = useState(args.value);
    useEffect(() => {
        setValue(args.value);
    }, [args.value]);
    const handleOnChange = (value) => {
        action('onChange')(value);
        setValue(value);
    };
    return _jsx(TextFieldDefault, Object.assign({}, args, { value: value, onChange: handleOnChange }), void 0);
};
export const Default = Template.bind({});
Default.args = {
    value: '',
    label: 'Text',
};
export const Email = Template.bind({});
Email.args = {
    label: 'Email',
    type: 'email',
    helperText: 'Please enter your email',
    value: 'email@example.com',
};
export const Password = Template.bind({});
Password.args = {
    label: 'Password',
    type: 'password',
    value: 'password',
    helperText: 'Please enter your password',
};
export const Error = Template.bind({});
Error.args = {
    error: true,
    label: 'Error',
    value: 'Error',
    helperText: 'Oops! This field has an invalid value',
};
export const ZipCodeMask = Template.bind({});
ZipCodeMask.args = {
    mask: [/\d/, /\d/, /\d/, /\d/, /\d/],
    label: 'Zip Code',
};
export const PhoneConfirmationMask = Template.bind({});
PhoneConfirmationMask.args = {
    maskGuide: true,
    mask: [/\d/, /\d/, /\d/, '-', /\d/, /\d/, /\d/, /\d/],
    label: 'Phone number',
};
export const ConfirmationCodeMask = Template.bind({});
ConfirmationCodeMask.args = {
    maskGuide: true,
    mask: (value = '') => {
        const maskArray = [];
        for (let i = 0; i < value.length; i += 1) {
            maskArray.push(/[a-zA-Z\-]/);
        }
        return maskArray;
    },
    label: 'Confirmation Code',
    pipe: (value = '') => {
        return value.toUpperCase();
    },
};
export const Multiline = Template.bind({});
Multiline.args = {
    label: 'Text',
    multiline: true,
};
//# sourceMappingURL=TextField.stories.js.map