import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { action } from '@storybook/addon-actions';
import { disabledArgTypes } from '../../helpers/storybookConstants';
import Link from '../Link';
import ToggleButtonGroupDefault, { ToggleButtonGroup, } from './ToggleButtonGroup';
export default {
    title: 'Components/ToggleButtonGroup',
    component: ToggleButtonGroup,
    argTypes: Object.assign({}, disabledArgTypes),
};
const Template = (args) => {
    const [value, setValue] = useState(args.value);
    useEffect(() => {
        setValue(args.value);
    }, [args.value]);
    const handleOnChange = (value) => {
        action('onChange')(value);
        setValue(value);
    };
    return (_jsx(ToggleButtonGroupDefault, Object.assign({}, args, { value: value, onChange: handleOnChange }), void 0));
};
export const Default = Template.bind({});
Default.args = {
    label: 'SVG Icon',
    exclusive: true,
    children: [
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-down" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-down.svg", alt: "arrow-down" }, void 0) }), "arrow-down"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-left" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-left.svg", alt: "arrow-left" }, void 0) }), "arrow-left"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-right" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-right.svg", alt: "arrow-right" }, void 0) }), "arrow-right"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-up" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-up.svg", alt: "arrow-up" }, void 0) }), "arrow-up"),
    ],
};
export const Text = Template.bind({});
Text.args = {
    label: 'Text',
    helperText: 'Helper text',
    exclusive: true,
    children: [
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "fit" }, { children: "Fit" }), "fit"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "fill" }, { children: "Fill" }), "fill"),
    ],
};
export const Disabled = Template.bind({});
Disabled.args = Object.assign(Object.assign({}, Text.args), { disabled: true });
export const HelperLink = Template.bind({});
HelperLink.args = Object.assign(Object.assign({}, Text.args), { helperText: _jsx(Link, { children: "Helper link" }, void 0) });
export const MultipleSelect = Template.bind({});
MultipleSelect.args = {
    label: 'Multiple Select (exclusive disabled)',
    children: [
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "SU" }, { children: "Sun" }), "SU"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "MO" }, { children: "Mon" }), "MO"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "TU" }, { children: "Tue" }), "TU"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "WE" }, { children: "Wed" }), "WE"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "TH" }, { children: "Thu" }), "TH"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "FR" }, { children: "Fri" }), "FR"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "SA" }, { children: "Sat" }), "SA"),
    ],
};
export const MultipleSelectWithDisabledOptions = Template.bind({});
MultipleSelectWithDisabledOptions.args = {
    children: [
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "SU", disabled: true }, { children: "Sun" }), "SU"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "MO" }, { children: "Mon" }), "MO"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "TU" }, { children: "Tue" }), "TU"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "WE" }, { children: "Wed" }), "WE"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "TH" }, { children: "Thu" }), "TH"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "FR" }, { children: "Fri" }), "FR"),
        _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "SA", disabled: true }, { children: "Sat" }), "SA"),
    ],
};
export const DeselectDisabled = (args) => {
    const { value: argsValue = 'arrow-down' } = args;
    const [value, setValue] = useState(argsValue);
    useEffect(() => {
        setValue(argsValue);
    }, [argsValue]);
    const handleOnChange = (value) => {
        if (value !== null) {
            action('onChange')(value);
            setValue(value);
        }
    };
    return (_jsxs(ToggleButtonGroupDefault, Object.assign({}, args, { value: value, onChange: handleOnChange, exclusive: true, label: "SVG Icon (Deselect disabled)" }, { children: [_jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-down" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-down.svg", alt: "arrow-down" }, void 0) }), "arrow-down"), _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-left" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-left.svg", alt: "arrow-left" }, void 0) }), "arrow-left"), _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-right" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-right.svg", alt: "arrow-right" }, void 0) }), "arrow-right"), _jsx(ToggleButtonGroupDefault.Button, Object.assign({ value: "arrow-up" }, { children: _jsx("img", { src: "https://assets.raydiant.com/images/arrow-up.svg", alt: "arrow-up" }, void 0) }), "arrow-up")] }), void 0));
};
//# sourceMappingURL=ToggleButtonGroup.stories.js.map