import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as React from 'react';
import Media from 'react-media';
import Button from '../../core/Button';
import Form from '../../core/Form';
import RadioGroup from '../../core/RadioGroup';
import TextField from '../../core/TextField';
import withStyles, { createStyles } from '../../core/withStyles';
import Column from '../../layout/Column';
export const AddDeviceMinHeight = 400;
const heightUpBp = `@media screen and (min-height: ${AddDeviceMinHeight}px)`;
const styles = (theme) => createStyles({
    root: {
        display: 'flex',
        alignItems: 'center',
        width: '100%',
        [heightUpBp]: {
            flexDirection: 'column',
            maxWidth: 400,
        },
    },
    cta: {
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        paddingRight: theme.spacing(2),
        [heightUpBp]: {
            paddingRight: 0,
            marginBottom: theme.spacing(2),
        },
    },
    form: {
        width: '100%',
        minWidth: 240,
        [heightUpBp]: {
            minWidth: 'none',
        },
    },
    subHeading: {
        fontWeight: 500,
        fontSize: theme.fontSizes.lg,
        whiteSpace: 'nowrap',
    },
    heading: {
        fontSize: theme.fontSizes.lg,
    },
    screen: {
        backgroundColor: '#292834',
        fontSize: theme.fontSizes.lg,
        color: 'white',
        display: 'flex',
        marginLeft: 'auto',
        marginRight: 'auto',
        alignItems: 'center',
        justifyContent: 'center',
        width: '192px',
        height: '108px',
        boxShadow: theme.shadows[1],
    },
    audioOnly: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
    },
    audioOnlyLabel: {
        marginRight: theme.spacing(2),
    },
});
export class AddDevice extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            activationCode: '',
            name: '',
            isAudioOnly: false,
        };
        this.handleSubmitRegisterDeviceForm = () => {
            const { onRegister } = this.props;
            const { activationCode, name, isAudioOnly } = this.state;
            onRegister({ activationCode, name, isAudioOnly });
        };
    }
    renderAudioOnly() {
        const { classes, testId, hideAudioOnly } = this.props;
        const { isAudioOnly } = this.state;
        if (hideAudioOnly)
            return null;
        return (_jsxs("div", Object.assign({ className: classes.audioOnly }, { children: [_jsx("span", Object.assign({ className: classes.audioOnlyLabel }, { children: "Is this an audio-only device?" }), void 0), _jsxs(RadioGroup, Object.assign({ inline: true, value: isAudioOnly ? 'yes' : 'no', onChange: (value) => this.setState({ isAudioOnly: value === 'yes' }), testId: `${testId}-audio-only` }, { children: [_jsx(RadioGroup.Option, { value: "yes", label: "Yes", testId: `${testId}-audio-only-yes` }, void 0), _jsx(RadioGroup.Option, { value: "no", label: "No", testId: `${testId}-audio-only-no` }, void 0)] }), void 0)] }), void 0));
    }
    render() {
        const { classes, headingText, loading, error, testId } = this.props;
        const { activationCode, name } = this.state;
        return (_jsxs("div", Object.assign({ className: classes.root }, { children: [_jsxs(Column, Object.assign({ className: classes.cta }, { children: [_jsx("span", Object.assign({ className: classes.heading }, { children: headingText }), void 0), _jsx(Media, Object.assign({ query: `(min-height: ${AddDeviceMinHeight}px)` }, { children: (matches) => (matches ? this.renderAudioOnly() : null) }), void 0), _jsx("div", Object.assign({ className: classes.screen }, { children: _jsx("span", { children: "WORD 1 - WORD 2" }, void 0) }), void 0), _jsx("div", Object.assign({ className: classes.subHeading }, { children: "Enter the code shown on your TV" }), void 0)] }), void 0), _jsx(Form, Object.assign({ className: classes.form, onSubmit: this.handleSubmitRegisterDeviceForm }, { children: _jsxs(Column, { children: [_jsx(Media, Object.assign({ query: `(min-height: ${AddDeviceMinHeight}px)` }, { children: (matches) => (matches ? null : this.renderAudioOnly()) }), void 0), _jsx(TextField, { label: "Activation Code", value: activationCode, onChange: (value) => this.setState({ activationCode: value }), error: !!error, helperText: error, mask: (value = '') => value.split('').map(() => /[a-zA-Z\-\s]/g), pipe: (value = '') => {
                                    const newValue = value.toUpperCase().replace(' ', '-');
                                    return {
                                        value: newValue,
                                        indexesOfPipedChars: [newValue.indexOf('-') - 1],
                                    };
                                }, testId: `${testId}-activation-code` }, void 0), _jsx(TextField, { label: "Name (Optional)", value: name, onChange: (value) => this.setState({ name: value }), testId: `${testId}-name` }, void 0), _jsx(Button, { type: "submit", label: "Activate", color: "progress", disabled: !activationCode.match(/^[A-Z]+-[A-Z]+$/) || loading, testId: `${testId}-submit` }, void 0)] }, void 0) }), void 0)] }), void 0));
    }
}
export default withStyles(styles)(AddDevice);
//# sourceMappingURL=AddDevice.js.map