import { jsx as _jsx } from "react/jsx-runtime";
import * as React from 'react';
import stateChanged from '../../helpers/stateChanged';
import withScrollConsumer from './withScrollConsumer';
const withVisibility = (Component) => {
    class ComponentWithVisibility extends React.Component {
        constructor() {
            super(...arguments);
            this.ref = React.createRef();
            this.state = {
                isTopVisible: false,
                isBottomVisible: false,
                isLeftVisible: false,
                isRightVisible: false,
                isFullyVisible: false,
                isPartiallyVisible: false,
                isNotVisible: false,
            };
        }
        computeVisibilityProps() {
            const { scrollTop = 0, scrollLeft = 0, offsetWidth = 0, offsetHeight = 0, } = this.props;
            const containerBounds = {
                top: scrollTop,
                bottom: scrollTop + offsetHeight,
                left: scrollLeft,
                right: scrollLeft + offsetWidth,
            };
            const { offsetTop = 0, offsetLeft = 0, scrollWidth = 0, scrollHeight = 0, } = this.ref.current || {};
            const elementBounds = {
                top: offsetTop,
                bottom: offsetTop + scrollHeight,
                left: offsetLeft,
                right: offsetLeft + scrollWidth,
            };
            const isAboveVisibleArea = elementBounds.bottom < containerBounds.top;
            const isBelowVisibleArea = elementBounds.top > containerBounds.bottom;
            const isLeftOfVisibleArea = elementBounds.right < containerBounds.left;
            const isRightOfVisibleArea = elementBounds.left > containerBounds.right;
            const isNotVisible = isAboveVisibleArea ||
                isBelowVisibleArea ||
                isLeftOfVisibleArea ||
                isRightOfVisibleArea;
            const isPartiallyVisible = !isNotVisible;
            const isHorizontallyOutOfBounds = isLeftOfVisibleArea || isRightOfVisibleArea;
            const isVerticallyOutOfBounds = isAboveVisibleArea || isBelowVisibleArea;
            const isTopVisible = !isBelowVisibleArea &&
                !isHorizontallyOutOfBounds &&
                elementBounds.top >= containerBounds.top;
            const isBottomVisible = !isAboveVisibleArea &&
                !isHorizontallyOutOfBounds &&
                elementBounds.bottom <= containerBounds.bottom;
            const isLeftVisible = !isRightOfVisibleArea &&
                !isVerticallyOutOfBounds &&
                elementBounds.left >= containerBounds.left;
            const isRightVisible = !isLeftOfVisibleArea &&
                !isVerticallyOutOfBounds &&
                elementBounds.right <= containerBounds.right;
            const isFullyVisible = isTopVisible && isBottomVisible && isLeftVisible && isRightVisible;
            const state = {
                isTopVisible,
                isBottomVisible,
                isLeftVisible,
                isRightVisible,
                isFullyVisible,
                isPartiallyVisible,
                isNotVisible,
            };
            if (stateChanged(state, this.state))
                this.setState(state);
        }
        componentDidMount() {
            this.computeVisibilityProps();
        }
        componentDidUpdate() {
            this.computeVisibilityProps();
        }
        render() {
            const { isTopVisible, isLeftVisible, isRightVisible, isBottomVisible, isFullyVisible, isPartiallyVisible, isNotVisible, } = this.state;
            return (_jsx(Component, Object.assign({ isTopVisible: isTopVisible, isLeftVisible: isLeftVisible, isRightVisible: isRightVisible, isBottomVisible: isBottomVisible, isPartiallyVisible: isPartiallyVisible, isFullyVisible: isFullyVisible, isNotVisible: isNotVisible, visibleElementRef: this.ref }, this.props), void 0));
        }
    }
    return withScrollConsumer(ComponentWithVisibility);
};
export default withVisibility;
//# sourceMappingURL=withVisibility.js.map