import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
// NOTE: PresentationBuilder is deprecated. Use PresentationForm and PresentationPreview instead.
// This component only exists to avoid breaking the RaydiantKit simulator.
// @ts-nocheck
import * as immutable from 'object-path-immutable';
import * as React from 'react';
import ActionBar from '../../core/ActionBar';
import Button from '../../core/Button';
import Form from '../../core/Form';
import ThemeBackground from '../../core/ThemeBackground';
import Link from '../../core/Link';
import Popover from '../../core/Popover';
import withStyles from '../../core/withStyles';
import withThemeSelector from '../../core/withThemeSelector';
import Callout from '../../core/Callout';
import ThemeSelector from '../../core/ThemeSelector';
import AffectedScreensPopover from '../../devices/AffectedScreensPopover';
import Hidden from '../../layout/Hidden';
import Scrollable from '../../layout/Scrollable';
import OneThirdLayout from '../../layout/OneThirdLayout';
import Spacer from '../../layout/Spacer';
import Text from '../../typography/Text';
import * as P from '../PresentationTypes';
import PresentationForm from '../PresentationForm';
import PresentationPreview from '../PresentationPreview';
import validatePresentation from './validatePresentation';
import hasPresentationChanged from './hasPresentationChanged';
import styles from './PresentationBuilder.styles';
export class PresentationBuilder extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            previewPresentation: this.props.presentation,
            validate: false,
            previewMode: this.props.previewMode,
            showAffectedDevices: false,
        };
        this.fileBlobs = {};
        this.handleSave = () => {
            if (this.validate().length === 0) {
                this.props.onSave();
            }
        };
        this.handleDone = () => {
            if (this.validate().length === 0) {
                this.props.onDone();
            }
        };
    }
    componentDidUpdate(prevProps) {
        const { presentation } = this.props;
        if (!prevProps.presentation && presentation) {
            this.setState({ previewPresentation: presentation });
        }
        if (prevProps.presentation &&
            presentation &&
            prevProps.presentation.id !== presentation.id
        // Commenting the below check out because it causes the preview to render when typing
        // into a property that was just added via conditional controls (ie. qr code url). This
        // started happening after updating the Dashboard to use the new playlist renderer code.
        // We'll need to find a better fix for the below issue (if it still exists) but leaving this
        // check in as documentation for when we update RaydiantKit to the latest playlist renderer.
        //
        // This is only here because of RaydiantKit in order to re-render the preview
        // when the values change outside of the form.
        // || Object.keys(prevProps.presentation.applicationVariables).length !==
        //   Object.keys(presentation.applicationVariables).length
        ) {
            this.setState({ previewPresentation: presentation });
        }
    }
    validate() {
        const { appVersion, minDuration, presentation } = this.props;
        this.setState({ validate: true });
        return validatePresentation(presentation, appVersion, minDuration);
    }
    renderWarnings() {
        const { initialPresentationState, presentation, appVersion, affectedDevices, localUploads, } = this.props;
        const warnings = [];
        if (initialPresentationState.appVersionId !== appVersion.id) {
            warnings.push('Saving will update content to the newer version of the app, and may cause visual changes.');
        }
        if (affectedDevices.length &&
            hasPresentationChanged(initialPresentationState, presentation, appVersion, localUploads)) {
            const count = affectedDevices.length;
            warnings.push(_jsxs("span", { children: ["Saving these changes will affect\u00A0", _jsx(Link, Object.assign({ onClick: () => this.setState({ showAffectedDevices: true }) }, { children: count > 1 ? `${count} screens` : '1 screen' }), void 0)] }, void 0));
        }
        return warnings.map((warning, i) => _jsx(Callout, { children: warning }, i));
    }
    renderPreview() {
        const { appVersion, children, localUploads, minDuration } = this.props;
        const { previewMode } = this.state;
        let { previewPresentation } = this.state;
        const isLoading = !appVersion || !previewPresentation;
        if (isLoading) {
            return (_jsx(ThemeSelector, Object.assign({ color: "dark" }, { children: _jsx(ThemeBackground, {}, void 0) }), void 0));
        }
        // Inject local upload file URL's into the preview.
        localUploads.forEach(({ path, localUrl }) => {
            previewPresentation = immutable.set(previewPresentation, [...path, 'url'], localUrl);
        });
        const previewErrors = previewPresentation
            ? validatePresentation(previewPresentation, appVersion, minDuration)
            : [];
        return (_jsx(ThemeSelector, Object.assign({ color: "dark" }, { children: _jsx(PresentationPreview, Object.assign({ appVersion: appVersion, previewMode: previewMode, onPreviewModeChange: (value) => this.setState({ previewMode: value }) }, { children: children(previewPresentation, previewErrors) }), void 0) }), void 0));
    }
    render() {
        const { initialPresentationState, presentation, appVersion, themes, onSave, affectedDevices, onBack, backToLabel, header, onDone, didSave, minDuration, localUploads, soundZones, playlists, selectedPlaylistPath, onBuilderStateChange, onPlaylistEdit, onPlaylistCreate, onPlaylistSelect, onStateChange, classes, } = this.props;
        const { showAffectedDevices, validate } = this.state;
        const isLoading = !initialPresentationState || !presentation || !appVersion;
        const isNew = presentation && !presentation.id;
        // Don't update the preview if there are any errors.
        const formErrors = validate
            ? validatePresentation(presentation, appVersion, minDuration)
            : [];
        // Disabled save if we're still loading, if the presentation is invalid (after save) or if
        // we're editing an existing presentation and there are no changes.
        const shouldDisableSave = isLoading ||
            formErrors.length > 0 ||
            (!isNew &&
                !hasPresentationChanged(initialPresentationState, presentation, appVersion, localUploads));
        const shouldDisableDone = shouldDisableSave && !didSave;
        return (_jsxs(OneThirdLayout, { children: [_jsxs(OneThirdLayout.ColumnSmall, { children: [_jsxs(Scrollable, { children: [_jsx(Hidden, Object.assign({ smUp: true }, { children: this.renderPreview() }), void 0), _jsxs(Form.Section, { children: [onBack && (_jsx(Hidden, Object.assign({ xsDown: true }, { children: _jsx(Button, { icon: "arrowLeft", label: backToLabel || 'Back', onClick: onBack }, void 0) }), void 0)), _jsx(Text, Object.assign({ muted: true }, { children: "Presentation Details" }), void 0), header && _jsx("div", { children: header }, void 0)] }, void 0), !isLoading && (_jsx(PresentationForm, { className: classes.inputs, presentation: presentation, appVersion: appVersion, errors: formErrors, themes: themes, soundZones: soundZones, playlists: playlists, selectedPlaylistPath: selectedPlaylistPath, onPlaylistEdit: onPlaylistEdit, onPlaylistCreate: onPlaylistCreate, onPlaylistSelect: onPlaylistSelect, onChange: (updatedPresentation, updatedLocalUploads) => {
                                        onStateChange(updatedPresentation, updatedLocalUploads);
                                        const updateErrors = validatePresentation(updatedPresentation, appVersion, minDuration);
                                        if (updateErrors.length === 0) {
                                            this.setState({ previewPresentation: updatedPresentation });
                                        }
                                    }, onBuilderStateChange: onBuilderStateChange }, void 0))] }, void 0), !isLoading && this.renderWarnings(), _jsxs(ActionBar, Object.assign({ condensed: true, color: "light" }, { children: [_jsx(Spacer, {}, void 0), onDone && (_jsx(Button, { label: "Done", color: "primary", disabled: shouldDisableDone, onClick: this.handleDone }, void 0)), onSave && (_jsxs(Popover.Anchor, { children: [_jsx(Button, { label: "Save", color: "progress", disabled: shouldDisableSave, onClick: this.handleSave }, void 0), _jsx(AffectedScreensPopover, { open: showAffectedDevices, devices: affectedDevices, onClose: () => this.setState({ showAffectedDevices: false }) }, void 0)] }, void 0))] }), void 0)] }, void 0), _jsx(OneThirdLayout.ColumnLarge, { children: this.renderPreview() }, void 0)] }, void 0));
    }
}
PresentationBuilder.defaultProps = {
    themes: [],
    soundZones: [],
    playlists: [],
    affectedDevices: [],
    localUploads: [],
    minDuration: 5,
    previewMode: P.PreviewMode.Horizontal,
};
export default withThemeSelector(withStyles(styles)(PresentationBuilder));
//# sourceMappingURL=PresentationBuilder.js.map