const getLocalUploadsForAppVars = (appVars, properties, fileBlobs, path) => {
    const localUploads = [];
    properties.forEach((property) => {
        const value = appVars[property.name];
        if (!value)
            return;
        if (property.type === 'file' &&
            typeof value === 'object' &&
            'url' in value &&
            fileBlobs[value.url]) {
            localUploads.push({
                path: [...path, property.name],
                file: fileBlobs[value.url],
                localUrl: value.url,
            });
        }
        // Recurse through array items for uploads.
        if (property.type === 'array' &&
            Array.isArray(value) &&
            property.properties) {
            value.forEach((itemValue, index) => {
                localUploads.push(...getLocalUploadsForAppVars(itemValue, property.properties || [], fileBlobs, [...path, property.name, index]));
            });
        }
    });
    return localUploads;
};
export default function getLocalUploads(presentation, appVersion, fileBlobs) {
    return getLocalUploadsForAppVars(presentation.applicationVariables, appVersion.presentationProperties, fileBlobs, ['applicationVariables']);
}
//# sourceMappingURL=getLocalUploads.js.map