import { jsx as _jsx } from "react/jsx-runtime";
import * as React from 'react';
const SelectedPathContext = React.createContext(null);
export default function withSelectedPath(Component) {
    class WrappedComponent extends React.Component {
        constructor() {
            super(...arguments);
            this.state = {
                selectedPath: [],
                prevSelectedPath: [],
            };
            this.setSelectedPath = (selectedPath) => {
                this.setState((state) => ({
                    selectedPath,
                    prevSelectedPath: state.selectedPath,
                }));
                this.props.onInputStateChange({ selectedPath });
            };
        }
        render() {
            // Nested array inputs need to share the selectedPath state from the top
            // level array input. React's context feature is used to pass selectedPath
            // and setSelectedPath to child array inputs.
            return (_jsx(SelectedPathContext.Consumer, { children: (context) => {
                    if (context) {
                        // Context is defined so we know we're rendering a child array input.
                        return (_jsx(Component, Object.assign({}, this.props, { selectedPath: context.selectedPath, prevSelectedPath: context.prevSelectedPath, setSelectedPath: context.setSelectedPath }), void 0));
                    }
                    return (_jsx(SelectedPathContext.Provider, Object.assign({ value: {
                            selectedPath: this.state.selectedPath,
                            prevSelectedPath: this.state.selectedPath,
                            setSelectedPath: this.setSelectedPath,
                        } }, { children: _jsx(Component, Object.assign({}, this.props, { selectedPath: this.state.selectedPath, prevSelectedPath: this.state.prevSelectedPath, setSelectedPath: this.setSelectedPath }), void 0) }), void 0));
                } }, void 0));
        }
    }
    // @ts-ignore
    return WrappedComponent;
}
//# sourceMappingURL=withSelectedPath.js.map