var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx } from "react/jsx-runtime";
import FileField from '../../../../core/FileField';
import FakeFileList from './FakeFileList';
const fileTypeAcceptMap = {
    image: [
        'image/png',
        'image/jpeg',
        'image/svg+xml',
        'image/bmp',
        'image/tiff',
        'image/gif',
    ],
    video: [
        'video/mp4',
        'video/mpeg',
        'video/quicktime',
        'video/x-m4v',
        'video/webm',
    ],
    spreadsheet: [
        'application/vnd.ms-excel',
        'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
    ],
    pdf: ['application/pdf'],
};
const FileInput = ({ label, value, fileType, constraints, helperText, error, disabled, onChange, createObjectURL, }) => {
    // FileField accepts a FileList as it's value so for existing uploads to display
    // the file name in the input we need to create a fake FileList.
    let fakeFileList;
    if (value && value.filename) {
        fakeFileList = new FakeFileList();
        fakeFileList.add(value.filename);
    }
    let accept = [];
    if (fileType) {
        accept = fileTypeAcceptMap[fileType] || [];
    }
    else if (constraints) {
        accept = constraints['content-types'] || [];
    }
    return (_jsx(FileField, { label: label, value: fakeFileList, helperText: helperText, error: error, disabled: disabled, accept: accept, onChange: (fileList) => __awaiter(void 0, void 0, void 0, function* () {
            if (fileList && fileList.length) {
                // We don't support multiple files per presentation property.
                const file = fileList[0];
                try {
                    onChange(
                    // Convert to expected file upload structure for API.
                    {
                        filename: file.name,
                        url: yield createObjectURL(file),
                        'content-type': file.type,
                        'content-length': file.size,
                    }, 
                    // The raw file blob is passed separately to allow for uploading.
                    file);
                }
                catch (error) {
                    console.error(`Failed to create object URL for file ${file.name}`, error);
                }
            }
        }), onClear: () => onChange(null, null) }, void 0));
};
export default FileInput;
//# sourceMappingURL=FileInput.js.map