import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { ThemeProvider } from '@material-ui/core/styles';
import { useState } from 'react';
import withStyles, { createStyles, } from '../../../../core/withStyles';
import useGoogleFilePicker from './useGoogleFilePicker';
import createTheme from '../../../../theme/createTheme';
import Button from '../../../../core/Button';
import FormHelperText from '../../../../internal/FormHelperText';
const styles = createStyles({
    default: {
        boxShadow: '0px 2px 4px rgba(0, 0, 0, 0.25)',
    },
    disabled: {
        borderColor: '#E3E3E2',
    },
    itemsSelected: {
        borderColor: '#E3E3E2',
    },
    label: {
        width: '100%',
        padding: '0 30px',
        overflow: 'hidden',
        textOverflow: 'ellipsis',
    },
});
function GoogleFilePickerInput(props) {
    var _a;
    const [selectedItemCount, setSelectedItemCount] = useState(0);
    const { classes, label, icon, disabled, helperText, error } = props;
    const theme = (_a = props.theme) !== null && _a !== void 0 ? _a : getDefaultTheme;
    const isDisabled = (!props.picker.accessToken && !props.picker.accessTokenUrl) || disabled;
    const onChangeCallback = (selection) => {
        var _a, _b;
        setSelectedItemCount((_b = (_a = selection.docs) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0);
        setIsPickerVisible(false);
        props.picker.onChangeCallback && props.picker.onChangeCallback(selection);
    };
    const [, setIsPickerVisible] = useGoogleFilePicker(Object.assign(Object.assign({}, props.picker), { onChangeCallback }));
    const onClickCallback = () => {
        setIsPickerVisible(true);
    };
    return (_jsx(ThemeProvider, Object.assign({ theme: theme }, { children: _jsxs("div", { children: [_jsx(Button, { fullWidth: true, color: !isDisabled ? 'default' : 'primary', onClick: onClickCallback, disabled: isDisabled, label: getLabel(label, selectedItemCount), icon: icon, classes: {
                        button: isDisabled
                            ? classes.disabled
                            : selectedItemCount > 0
                                ? classes.itemsSelected
                                : classes.default,
                    } }, void 0), helperText && (_jsx(FormHelperText, Object.assign({ error: error, disabled: disabled }, { children: helperText }), void 0))] }, void 0) }), void 0));
}
function getLabel(label, selectedItemCount) {
    if (label) {
        return label;
    }
    if (selectedItemCount === 0) {
        return 'Select Google Drive Item';
    }
    else if (selectedItemCount === 1) {
        return 'Selected 1 Google Drive Item';
    }
    else {
        return `Selected ${selectedItemCount} Google Drive Items`;
    }
}
function getDefaultTheme(outerTheme) {
    return createTheme(Object.assign(Object.assign({}, outerTheme), { palette: Object.assign(Object.assign({}, outerTheme.palette), { primary: {
                main: '#003670',
                dark: '#002B5A',
                contrastText: '#ffffff',
            } }), button: Object.assign(Object.assign({}, outerTheme.button), { background: '#7A93B2', foregroundMuted: '#ffffff' }) }));
}
export default withStyles(styles)(GoogleFilePickerInput);
//# sourceMappingURL=GoogleFilePickerInput.js.map