/// <reference types="google.picker" />
import { Dispatch, SetStateAction } from 'react';
import { PresentationValuesType } from './urlInterpolation';
export declare const GOOGLE_API_SCRIPT_URL = "https://apis.google.com/js/api.js";
export declare const GOOGLE_API_NAME = "gapi";
export declare type ViewId = 'all' | 'docs-images' | 'docs-images-and-videos' | 'docs-videos' | 'documents' | 'drawings' | 'folders' | 'forms';
export interface View {
    readonly viewId: ViewId;
    readonly setIncludeFolders?: boolean;
    readonly setSelectFolderEnabled?: boolean;
}
export declare const defaults: Required<Pick<GoogleFilePickerProps, 'title' | 'views' | 'onChangeCallback'>>;
export interface GoogleFilePickerProps {
    readonly developerKey: string;
    /**
     * for test purposes access token can be aquired using:
     * https://developers.google.com/oauthplayground
     */
    readonly accessToken: string;
    /**
     * URL which can be used to aquire access token.
     * URL supports interpolation so if URL would look like:
     * https://gallery-backend.raydiant.com/google/token?api_key={{apiKey}}
     * {{apiKey}} would be substituted with apiKey variable from presentation
     * values.
     */
    readonly accessTokenUrl: string;
    readonly presentationValues: PresentationValuesType;
    readonly title?: string;
    readonly onChangeCallback?: (result: google.picker.ResponseObject) => void;
    readonly views?: View[];
}
export default function useGoogleFilePicker(props: GoogleFilePickerProps): [boolean, Dispatch<SetStateAction<boolean>>];
