var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useEffect, useState, useMemo } from 'react';
import { getInterpolatedUrl } from './urlInterpolation';
import { READY, useScript } from './useScript';
export const GOOGLE_API_SCRIPT_URL = 'https://apis.google.com/js/api.js';
export const GOOGLE_API_NAME = 'gapi';
export const defaults = {
    title: 'Select a file',
    views: [
        {
            viewId: 'docs-images-and-videos',
            setIncludeFolders: true,
        },
    ],
    onChangeCallback: (result) => { },
};
export default function useGoogleFilePicker(props) {
    const { developerKey, accessTokenUrl, presentationValues, title = defaults.title, onChangeCallback = defaults.onChangeCallback, views = defaults.views, } = props;
    const apiScriptStatus = useScript({
        url: GOOGLE_API_SCRIPT_URL,
        name: GOOGLE_API_NAME,
    });
    const [dependenciesLoaded, setDependenciesLoaded] = useState(false);
    const [picker, setPicker] = useState(undefined);
    const [accessToken, setAccessToken] = useState(props.accessToken);
    const [isPickerVisible, setIsPickerVisible] = useState(false);
    const interpolatedAccessTokenUrl = useMemo(() => {
        if (accessToken) {
            return;
        }
        if (!accessToken && !accessTokenUrl) {
            console.warn('AccessToken or AccessTokenUrl must be provided for GoogleFilePickerInput.');
            return;
        }
        return getInterpolatedUrl({
            url: accessTokenUrl,
            presentationValues,
        });
    }, [accessToken, accessTokenUrl, presentationValues]);
    useEffect(() => {
        if (!interpolatedAccessTokenUrl) {
            return;
        }
        const fetchAccessToken = () => __awaiter(this, void 0, void 0, function* () {
            const response = yield fetch(interpolatedAccessTokenUrl);
            if (response.ok) {
                const { accessToken } = yield response.json();
                setAccessToken(accessToken);
            }
            else {
                console.warn(`Failed to fetch Google accessToken. Response status: ${response.status}, status text: ${response.statusText}.`);
            }
        });
        fetchAccessToken().catch((error) => {
            console.warn(`Failed to fetch Google accessToken. Error: ${error}.`);
        });
    }, [interpolatedAccessTokenUrl]);
    useEffect(() => {
        if (!dependenciesLoaded && apiScriptStatus === READY) {
            gapi.load('picker', () => setDependenciesLoaded(true));
        }
    }, [dependenciesLoaded, apiScriptStatus]);
    useEffect(() => {
        if (!dependenciesLoaded || picker || !accessToken) {
            return;
        }
        const callback = (selection) => {
            if (selection[google.picker.Response.ACTION] ===
                google.picker.Action.CANCEL ||
                selection[google.picker.Response.ACTION] === google.picker.Action.PICKED) {
                onChangeCallback(selection);
            }
        };
        const googlePickerBuilder = new google.picker.PickerBuilder()
            .setTitle(title)
            .setOAuthToken(accessToken)
            .setDeveloperKey(developerKey)
            .setCallback(callback);
        views.forEach((view) => {
            const viewObject = new google.picker.DocsView(view.viewId);
            if (view.setIncludeFolders !== undefined) {
                viewObject.setIncludeFolders(view.setIncludeFolders);
            }
            if (view.setSelectFolderEnabled !== undefined) {
                viewObject.setSelectFolderEnabled(view.setSelectFolderEnabled);
            }
            googlePickerBuilder.addView(viewObject);
        });
        const goolgePicker = googlePickerBuilder.build();
        setPicker(goolgePicker);
        return () => goolgePicker.dispose();
    }, [
        dependenciesLoaded,
        picker,
        accessToken,
        views,
        developerKey,
        title,
        onChangeCallback,
    ]);
    useEffect(() => {
        if (!picker || !accessToken) {
            return;
        }
        picker.setVisible(isPickerVisible);
    }, [dependenciesLoaded, accessToken, picker, isPickerVisible]);
    return [isPickerVisible, setIsPickerVisible];
}
//# sourceMappingURL=useGoogleFilePicker.js.map