var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { ThemeProvider } from '@material-ui/core/styles';
import * as React from 'react';
import Button from '../../../../core/Button';
import Link from '../../../../core/Link';
import withStyles, { createStyles, } from '../../../../core/withStyles';
import FormHelperText from '../../../../internal/FormHelperText';
import createTheme from '../../../../theme/createTheme';
const styles = createStyles({
    default: {
        boxShadow: '0px 2px 4px rgba(0, 0, 0, 0.25)',
    },
    disabled: {
        borderColor: '#E3E3E2',
    },
    loggedIn: {
        borderColor: '#E3E3E2',
    },
    label: {
        width: '100%',
        padding: '0 30px',
        overflow: 'hidden',
        textOverflow: 'ellipsis',
    },
});
class OAuthInput extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            username: '',
            verifyStatus: 'idle',
        };
        this.authRedirect = () => {
            const { authUrl } = this.props;
            const url = new URL(authUrl);
            url.searchParams.set('prop', this.serializePropPath());
            url.searchParams.set('dash-uri', window.location.href);
            window.location.href = url.href;
        };
        this.logout = () => {
            const { value, logoutUrl, logoutQsParam, onChange } = this.props;
            this.setState({ username: null, verifyStatus: 'idle' });
            onChange(null);
            if (logoutUrl) {
                // We don't care about the response.
                fetch(`${logoutUrl}?${logoutQsParam}=${value}`, {
                    method: 'POST',
                    mode: 'no-cors',
                });
            }
        };
        this.getHelperContent = () => {
            const { disabled, helperText } = this.props;
            const { verifyStatus } = this.state;
            if (verifyStatus === 'success') {
                return (_jsx(Link, Object.assign({ onClick: this.logout, disabled: disabled }, { children: "Disconnect" }), void 0));
            }
            else if (verifyStatus === 'failed') {
                return 'Account not connected, please try again.';
            }
            return helperText;
        };
    }
    componentDidMount() {
        const { value } = this.props;
        if (value) {
            this.verify(value);
        }
    }
    componentDidUpdate(prevProps) {
        const { value } = this.props;
        if (value && value !== prevProps.value) {
            this.verify(value);
        }
    }
    verify(accessToken) {
        return __awaiter(this, void 0, void 0, function* () {
            const { verifyUrl, verifyQsParam, previewUsername, previewVerifyStatus } = this.props;
            if (previewUsername || previewVerifyStatus) {
                this.setState({
                    username: previewUsername,
                    verifyStatus: previewVerifyStatus,
                });
                return;
            }
            const res = yield fetch(`${verifyUrl}?${verifyQsParam}=${accessToken}`);
            if (res.ok) {
                const { username } = yield res.json();
                this.setState({ username, verifyStatus: 'success' });
            }
            else {
                this.setState({ verifyStatus: 'failed' });
            }
        });
    }
    serializePropPath() {
        // Prop paths are an array, we need to serialize them to pass it through the auth redirects.
        return this.props.path.join('.');
    }
    render() {
        const { classes, error, disabled, icon, label, provider, theme } = this.props;
        const { username, verifyStatus } = this.state;
        const hasError = error || verifyStatus === 'failed';
        const verified = verifyStatus === 'success';
        const buttonLabel = verified
            ? username
                ? `Connected as ${username}`
                : `Connected to ${provider}`
            : label;
        const helperContent = this.getHelperContent();
        return (
        // @ts-ignore
        _jsx(ThemeProvider, Object.assign({ theme: theme }, { children: _jsxs("div", { children: [_jsx(Button, { fullWidth: true, color: verified && !disabled ? 'default' : 'primary', onClick: verified ? () => { } : this.authRedirect, disabled: disabled || verified, label: buttonLabel, icon: icon, classes: {
                            button: disabled
                                ? classes.disabled
                                : verified
                                    ? classes.loggedIn
                                    : classes.default,
                        } }, void 0), helperContent && (_jsx(FormHelperText, Object.assign({ error: hasError, disabled: disabled }, { children: helperContent }), void 0))] }, void 0) }), void 0));
    }
}
OAuthInput.defaultProps = {
    theme: (outerTheme) => createTheme(Object.assign(Object.assign({}, outerTheme), { palette: Object.assign(Object.assign({}, outerTheme.palette), { primary: {
                main: '#003670',
                dark: '#002B5A',
                contrastText: '#ffffff',
            } }), button: Object.assign(Object.assign({}, outerTheme.button), { background: '#7A93B2', foregroundMuted: '#ffffff' }) })),
};
export default withStyles(styles)(OAuthInput);
//# sourceMappingURL=OAuthInput.js.map