var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
// import * as React from 'react';
import { useEffect, useState, useCallback } from 'react';
import { ThemeProvider } from '@material-ui/core/styles';
import Button from '../../../../core/Button';
import Link from '../../../../core/Link';
import createTheme from '../../../../theme/createTheme';
import { makeStyles, createStyles } from '../../../../styles';
import FormHelperText from '../../../../internal/FormHelperText';
const OAuthInput2 = ({ path, provider, value, disabled, error, iconUrl, authUrl, verifyUrl, verifyQsParam, logoutUrl, logoutQsParam, backgroundColor, foregroundColor, helperText, onChange, }) => {
    const classes = useStyles();
    const [username, setUsername] = useState(null);
    const [verifyStatus, setVerifyStatus] = useState('idle');
    const authorize = () => {
        const url = new URL(authUrl);
        url.searchParams.set('prop', path.join('.'));
        url.searchParams.set('dash-uri', window.location.href);
        // TODO: props.authPropQsParam and props.authRedirectQsParam?
        window.location.href = url.href;
    };
    const verify = useCallback((token) => __awaiter(void 0, void 0, void 0, function* () {
        setVerifyStatus('pending');
        const url = new URL(verifyUrl);
        url.searchParams.set(verifyQsParam || 'token', token);
        // TODO: props.verifyHeaders and props.verifyMethod?
        const response = yield fetch(url.href);
        if (response.ok) {
            const { username } = yield response.json();
            setUsername(username);
            setVerifyStatus('success');
        }
        else {
            setVerifyStatus('failed');
        }
    }), [verifyUrl, verifyQsParam]);
    const logout = (token) => __awaiter(void 0, void 0, void 0, function* () {
        setUsername(null);
        setVerifyStatus('idle');
        onChange(null);
        const url = new URL(logoutUrl);
        url.searchParams.set(logoutQsParam || 'token', token);
        // TODO: props.logoutHeaders and props.logoutMethod?
        yield fetch(url.href, { method: 'POST' });
    });
    const createStableTheme = useCallback((outerTheme) => {
        return createTheme(Object.assign(Object.assign({}, outerTheme), { palette: Object.assign(Object.assign({}, outerTheme.palette), { primary: Object.assign(Object.assign({}, outerTheme.palette.primary), { main: backgroundColor || outerTheme.palette.primary.main, dark: backgroundColor || outerTheme.palette.primary.dark, contrastText: foregroundColor }) }), button: Object.assign(Object.assign({}, outerTheme.button), { background: backgroundColor || outerTheme.button.background, foreground: foregroundColor || outerTheme.button.foreground, border: backgroundColor || outerTheme.button.border }) }));
    }, [backgroundColor, foregroundColor]);
    useEffect(() => {
        if (value) {
            verify(value);
        }
    }, [value, verify]);
    let label = `Connect to ${provider}`;
    if (verifyStatus === 'success') {
        if (username) {
            label = `Connected as ${username}`;
        }
        else {
            label = `Connected to ${provider}`;
        }
    }
    let helperContent = helperText;
    if (verifyStatus === 'success' && value) {
        helperContent = (_jsx(Link, Object.assign({ onClick: () => logout(value), disabled: disabled }, { children: "Disconnect" }), void 0));
    }
    else if (verifyStatus === 'failed') {
        helperContent = 'Account not connected, please try again.';
    }
    let icon = null;
    if (iconUrl) {
        icon = _jsx("img", { className: classes.icon, src: iconUrl, alt: provider }, void 0);
    }
    const oAuthButton = (_jsxs("div", { children: [_jsx(Button, { fullWidth: true, label: label, icon: icon, color: verifyStatus === 'pending' || verifyStatus === 'success'
                    ? 'default'
                    : 'primary', disabled: verifyStatus === 'pending' || verifyStatus === 'success' || disabled, onClick: authorize }, void 0), _jsx(FormHelperText, Object.assign({ error: error || verifyStatus === 'failed', disabled: disabled }, { children: helperContent }), void 0)] }, void 0));
    if (backgroundColor || foregroundColor) {
        return (_jsx(ThemeProvider, Object.assign({ theme: createStableTheme }, { children: oAuthButton }), void 0));
    }
    return oAuthButton;
};
const useStyles = makeStyles((theme) => createStyles({
    icon: {
        width: 24,
        height: 24,
    },
}));
export default OAuthInput2;
//# sourceMappingURL=OAuthInput2.js.map