import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import * as React from 'react';
import Button from '../../../../core/Button';
import SelectField from '../../../../core/SelectField';
import Row from '../../../../layout/Row';
export const NEW_PLAYLIST_VALUE = 'new';
class PlaylistInput extends React.Component {
    constructor() {
        super(...arguments);
        this.handleChange = (value) => {
            const { onChange = () => { }, onCreate = () => { } } = this.props;
            if (value === NEW_PLAYLIST_VALUE) {
                onCreate();
            }
            else {
                onChange(value);
            }
        };
    }
    componentDidMount() {
        this.checkDefaultValue();
    }
    componentDidUpdate(prevProps) {
        const { playlists } = this.props;
        const didPlaylistsChange = playlists.length !== prevProps.playlists.length ||
            playlists.some((p, i) => p.id !== prevProps.playlists[i].id);
        if (didPlaylistsChange) {
            this.checkDefaultValue();
        }
    }
    checkDefaultValue() {
        const { value, propertyTypeIndex, playlists, onChange } = this.props;
        // Set default playlist if one doesn't exist. Uses propertyTypeIndex to pick
        // another playlist when there are multiple zones.
        if (playlists.length > 0 && (!value || !this.isValueInPlaylists())) {
            this.onChangeTimeout = setTimeout(() => {
                // This ensures we pick the second playlist as the default for zone2 of MZ
                // if there is more than one user playlist.
                const defaultPlaylistIndex = Math.min(propertyTypeIndex, playlists.length - 1);
                onChange(playlists[defaultPlaylistIndex].id);
            });
        }
    }
    isValueInPlaylists() {
        const { value, playlists } = this.props;
        return !!playlists.map((pl) => pl.id).includes(value);
    }
    componentWillUnmount() {
        clearTimeout(this.onChangeTimeout);
    }
    render() {
        const { label, value, playlists, helperText, error, disabled, onEdit, onCreate, } = this.props;
        const options = playlists.map((pl) => ({
            value: pl.id,
            name: pl.name,
        }));
        const valueOrDefault = value || (options[0] ? options[0].value : '');
        if (onCreate && !playlists.length) {
            return (_jsx(Button, { color: "primary", label: `Create a Playlist for ${label}`, onClick: onCreate, disabled: disabled }, void 0));
        }
        return (_jsxs(Row, { children: [_jsxs(SelectField, Object.assign({ label: label, value: valueOrDefault, onChange: this.handleChange, helperText: helperText, error: error, disabled: disabled }, { children: [onCreate && (_jsxs(_Fragment, { children: [_jsx("option", Object.assign({ value: NEW_PLAYLIST_VALUE }, { children: "New Empty Playlist" }), void 0), _jsx("option", Object.assign({ value: "new-separator", disabled: true }, { children: "--------------------------" }), void 0)] }, void 0)), options.map((opt) => (_jsx("option", Object.assign({ value: opt.value }, { children: opt.name }), opt.value))), options.length === 0 && _jsx("option", Object.assign({ disabled: true }, { children: "No playlists found" }), void 0)] }), void 0), onEdit && (_jsx("div", Object.assign({ style: { marginTop: 19 } }, { children: _jsx(Button, { icon: "edit", disabled: disabled, onClick: () => onEdit(valueOrDefault) }, void 0) }), void 0))] }, void 0));
    }
}
export default PlaylistInput;
//# sourceMappingURL=PlaylistInputLegacy.js.map