import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as React from 'react';
import SelectField from '../../../../core/SelectField';
class SoundZone extends React.Component {
    componentDidMount() {
        this.checkDefaultValue();
    }
    componentDidUpdate(prevProps) {
        const { soundZones } = this.props;
        const didSoundZonesChange = soundZones.length !== prevProps.soundZones.length ||
            soundZones.some((sz, i) => sz.id !== prevProps.soundZones[i].id);
        if (didSoundZonesChange) {
            this.checkDefaultValue();
        }
    }
    checkDefaultValue() {
        const { value, soundZones, onChange } = this.props;
        // Default to first sound zone if value is not set.
        if (!value && soundZones.length > 0) {
            this.onChangeTimeout = setTimeout(() => {
                onChange(soundZones[0].id);
            });
        }
    }
    componentWillUnmount() {
        clearTimeout(this.onChangeTimeout);
    }
    render() {
        const { label, value, soundZones, helperText, error, disabled, onChange } = this.props;
        const soundZone = soundZones.find((sz) => sz.id === value);
        // Assume the soundzone was assigned by an admin if there is a soundzone id but we can't
        // find it in the current user's soundzones. This is a workaround, ideally the API would return
        // the basic information about the assigned soundzone if the current user doesn't have access to it.
        const isAdminAssigned = value && !soundZone;
        const options = soundZones.map((sz) => ({
            value: sz.id,
            name: sz.name,
        }));
        return (_jsxs(SelectField, Object.assign({ label: label, value: value || (options[0] ? options[0].value : ''), onChange: onChange, helperText: helperText, error: error, disabled: disabled }, { children: [isAdminAssigned && (_jsx("option", Object.assign({ value: value }, { children: " Administrator assigned sound zone" }), void 0)), options.map((opt) => (_jsx("option", Object.assign({ value: opt.value }, { children: opt.name }), opt.value))), options.length === 0 && (_jsx("option", Object.assign({ disabled: true }, { children: "No paired zones found" }), void 0))] }), void 0));
    }
}
export default SoundZone;
//# sourceMappingURL=SoundZoneInput.js.map