import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import HttpsIcon from '@material-ui/icons/Https';
import cn from 'classnames';
import isTouchDevice from 'is-touch-device';
import * as React from 'react';
import AlertIcon from '../../core/AlertIcon';
import Button from '../../core/Button';
import Checkbox from '../../core/Checkbox';
import CircularProgress from '../../core/CircularProgress';
import withStyles from '../../core/withStyles';
import { stopPropagation, testAttr } from '../../helpers';
import Scrollable from '../../layout/Scrollable';
import styles from './PresentationThumbnail.styles';
export class PresentationThumbnail extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            isHover: false,
            editPopoverOpen: false,
        };
        this.handleMouseOver = () => {
            this.setState({ isHover: true });
        };
        this.handleMouseLeave = () => {
            this.setState({ isHover: false });
        };
    }
    render() {
        const { classes, presentation, selected = false, showControls, hasError, errorMessage, isLoading, onEdit, onSelect, onClick, isLocked, testId, } = this.props;
        const { isHover, editPopoverOpen } = this.state;
        const imageUrl = presentation.thumbnailUrl || presentation.applicationThumbnailUrl;
        const hasControls = onEdit || onSelect;
        const shouldShowIcon = presentation.hasDynamicThumbnails &&
            presentation.thumbnailUrl &&
            !isLocked;
        const shouldShowControls = showControls || (hasControls && isHover) || editPopoverOpen;
        const shouldShowEdit = !isLocked && onEdit && shouldShowControls;
        const shouldShowSelect = (onSelect && shouldShowControls) || selected;
        const shouldShowError = hasError && !shouldShowSelect;
        const shouldShowProgress = isLoading;
        const shouldShowOverlay = shouldShowControls || hasError || isLoading || selected;
        // Don't attached mouse over / leave for touch devices.
        const shouldAddMouseEvents = !isTouchDevice();
        return (_jsxs("div", Object.assign({ className: cn(classes.root, onClick && classes.clickable), onMouseOver: shouldAddMouseEvents ? this.handleMouseOver : undefined, onMouseLeave: shouldAddMouseEvents ? this.handleMouseLeave : undefined, onClick: onClick }, testAttr(testId), { children: [_jsx("div", { className: classes.image, style: {
                        backgroundImage: `url(${imageUrl})`,
                    } }, void 0), shouldShowIcon && (_jsx("div", { className: cn(classes.icon, classes.bottomLeft), style: {
                        backgroundImage: `url(${presentation.iconUrl})`,
                    } }, void 0)), shouldShowOverlay && _jsx("div", { className: classes.overlay }, void 0), shouldShowProgress && (_jsx("div", Object.assign({ className: classes.topRight }, { children: _jsx(CircularProgress, { color: "light" }, void 0) }), void 0)), shouldShowError && (_jsxs("div", Object.assign({ className: cn(classes.topLeft, classes.error) }, { children: [_jsx(AlertIcon, {}, void 0), _jsx("span", Object.assign({ className: classes.errorMessage }, { children: errorMessage }), void 0)] }), void 0)), shouldShowEdit && (_jsx("div", Object.assign({ className: shouldShowSelect ? classes.topRight : classes.topLeft }, { children: _jsx(Button, { color: "light", icon: "edit", onClick: stopPropagation(onEdit), testId: testId ? `${testId}-edit` : '' }, void 0) }), void 0)), isLocked && (_jsx("div", Object.assign({ className: classes.lock }, { children: _jsx(HttpsIcon, { fontSize: "inherit" }, void 0) }), void 0)), shouldShowSelect && (_jsx(Scrollable.VisibilitySensor, { children: ({ visibilityRef, isVisible }) => (_jsx("div", Object.assign({ ref: visibilityRef, className: classes.topLeft }, { children: isVisible && (_jsx(Checkbox, { round: true, checked: selected, onChange: onSelect, onClick: stopPropagation(), testId: testId ? `${testId}-select` : '' }, void 0)) }), void 0)) }, void 0))] }), void 0));
    }
}
PresentationThumbnail.defaultProps = {
    selected: false,
    showControls: false,
    hasError: false,
    errorMessage: '',
    isLoading: false,
};
export default withStyles(styles)(PresentationThumbnail);
//# sourceMappingURL=PresentationThumbnail.js.map