import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import cn from 'classnames';
import moment from 'moment';
import Icon from '../../core/Icon';
import withStyles, { createStyles } from '../../core/withStyles';
import { testAttr } from '../../helpers';
import Heading2 from '../../typography/Heading2';
import Text from '../../typography/Text';
export const OccurrenceListItem = ({ classes, name, start, end, overridden, locked, recurring, onClick, testId, }) => {
    const startTime = moment(start);
    const endTime = moment(end);
    const sameDate = startTime.isSame(endTime, 'date');
    const sameYear = startTime.year() === endTime.year();
    let dateFormat = 'h:mm A';
    if (!sameDate && !sameYear) {
        dateFormat = `${dateFormat} (MMM D, YY)`;
    }
    else if (!sameDate) {
        dateFormat = `${dateFormat} (MMM D)`;
    }
    const startTimeText = startTime.format(dateFormat);
    const endTimeText = endTime.format(dateFormat);
    const occurrenceName = overridden ? (_jsx(Text, Object.assign({ small: true, strikethrough: true, ellipsis: true }, { children: name }), void 0)) : (_jsx(Heading2, Object.assign({ ellipsis: true }, { children: name }), void 0));
    return (_jsxs("div", Object.assign({ onClick: onClick, className: cn(classes.root, onClick && classes.clickable) }, testAttr(testId), { children: [_jsxs("div", Object.assign({ className: cn(classes.content, overridden && classes.overridden) }, { children: [occurrenceName, _jsxs("div", Object.assign({ className: classes.duration }, { children: [_jsx(Text, Object.assign({ small: true, muted: true, ellipsis: !overridden }, { children: startTimeText }), void 0), _jsx(Text, Object.assign({ small: true, muted: true }, { children: "\u00A0\u2013\u00A0" }), void 0), _jsx(Text, Object.assign({ small: true, muted: true, ellipsis: !overridden }, { children: endTimeText }), void 0)] }), void 0)] }), void 0), _jsxs("div", Object.assign({ className: classes.badges }, { children: [recurring && (_jsx(Icon, { icon: "repeat", className: cn(classes.badge, classes.repeat) }, void 0)), locked && (_jsx(Icon, { icon: "lock", className: cn(classes.badge, classes.lock) }, void 0))] }), void 0)] }), void 0));
};
const styles = (theme) => createStyles({
    root: {
        display: 'flex',
        borderBottomWidth: 1,
        borderBottomStyle: 'solid',
        borderBottomColor: theme.divider.secondary,
        '&:first-child': {
            borderTopLeftRadius: 2,
            borderTopRightRadius: 2,
        },
        '&:last-child': {
            borderBottomLeftRadius: 2,
            borderBottomRightRadius: 2,
        },
        backgroundColor: theme.palette.background.default,
        whiteSpace: 'nowrap',
    },
    content: {
        flex: 1,
        display: 'flex',
        flexDirection: 'column',
        paddingLeft: theme.spacing(2),
        paddingRight: theme.spacing(2),
        paddingTop: theme.spacing(1),
        paddingBottom: theme.spacing(1),
    },
    overridden: {
        display: 'inline-flex',
        flexDirection: 'row',
        justifyContent: 'space-between',
        flexWrap: 'wrap',
    },
    duration: {
        display: 'flex',
        flexShrink: 0,
        flexWrap: 'wrap',
    },
    badges: {
        flex: 0,
    },
    badge: {
        color: theme.palette.background.default,
        '&:first-child': {
            borderBottomLeftRadius: 2,
        },
    },
    lock: {
        backgroundColor: theme.palette.warning.main,
        // shrink lock icon to match line thickness of repeat icon
        padding: 2,
        boxSizing: 'border-box',
    },
    repeat: {
        backgroundColor: theme.palette.progress.main,
    },
    clickable: {
        cursor: 'pointer',
    },
});
export default withStyles(styles)(OccurrenceListItem);
//# sourceMappingURL=OccurrenceListItem.js.map