import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import moment from 'moment';
import * as React from 'react';
import withStyles, { createStyles } from '../../core/withStyles';
import withThemeSelector from '../../core/withThemeSelector';
import stateChanged from '../../helpers/stateChanged';
import withScrollProvider from '../../internal/Scroll/withScrollProvider';
import { scrollable } from '../../mixins';
import Text from '../../typography/Text';
import SequenceScheduleContext from './SequenceScheduleContext';
import SequenceScheduleDay from './SequenceScheduleDay';
import SequenceScheduleMonth from './SequenceScheduleMonth';
export class SequenceSchedule extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            monthVisibility: {},
            currentMonth: moment().startOf('month').toDate(),
        };
        this.setMonthVisibility = (month, visibility) => {
            const monthVisibility = Object.assign(Object.assign({}, this.state.monthVisibility), { [month.toISOString()]: visibility });
            if (stateChanged(monthVisibility, this.state.monthVisibility)) {
                const currentMonth = Object.keys(monthVisibility)
                    .filter((monthStr) => monthVisibility[monthStr])
                    .map((monthStr) => new Date(monthStr))
                    .sort((month1, month2) => +month1 - +month2)[0];
                this.setState({ currentMonth, monthVisibility });
            }
        };
    }
    render() {
        const { children, classes, onScroll } = this.props;
        const { currentMonth } = this.state;
        return (_jsxs("div", Object.assign({ className: classes.root }, { children: [_jsx("div", Object.assign({ className: classes.currentMonthHeader }, { children: _jsx(Text, Object.assign({ muted: true, nowrap: true }, { children: moment(currentMonth).format('MMMM YYYY') }), void 0) }), void 0), _jsx("div", Object.assign({ className: classes.months, onScroll: onScroll }, { children: _jsx(SequenceScheduleContext.Provider, Object.assign({ value: {
                            setMonthVisibility: this.setMonthVisibility,
                        } }, { children: children }), void 0) }), void 0)] }), void 0));
    }
}
const styles = (theme) => createStyles({
    root: {
        display: 'flex',
        flexDirection: 'column',
        flex: 1,
        overflow: 'hidden',
    },
    currentMonthHeader: {
        paddingTop: theme.spacing(1),
        paddingBottom: theme.spacing(1),
        paddingLeft: theme.spacing(2),
        paddingRight: theme.spacing(2),
        borderBottomColor: theme.divider.secondary,
        borderBottomStyle: 'solid',
        borderBottomWidth: 1,
    },
    months: Object.assign(Object.assign({}, scrollable()), { position: 'relative' }),
});
export default Object.assign(
// @ts-ignore
withScrollProvider(withThemeSelector(withStyles(styles)(SequenceSchedule))), {
    Day: SequenceScheduleDay,
    Month: SequenceScheduleMonth,
});
//# sourceMappingURL=SequenceSchedule.js.map